@@ -1,9 +1,10 @@
 use strict;
 use warnings;
+# ABSTRACT: a tolerance "m <= n"
 
 package
   Number::Tolerant::Type::or_less;
-use base qw(Number::Tolerant::Type);
+use parent qw(Number::Tolerant::Type);
 
 sub construct { shift; { value => $_[0], max => $_[0] } }
 
@@ -33,15 +34,18 @@ sub valid_args {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Number::Tolerant::Type::or_less
+Number::Tolerant::Type::or_less - a tolerance "m <= n"
 
 =head1 VERSION
 
-version 1.701
+version 1.704
 
 =head1 AUTHOR
 
@@ -55,4 +59,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
